@@ -325,7 +325,7 @@ class BinoutData(object):
             # ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
             #                           self._binout.read(self._name, elem_name, "ids") for elem_name in keys])
         else:
-            ids_list = self._binout.read(self._name, "ids")
+            ids_list = self._binout.read(self._name, self.ids_name)
 
         for sec in dyn_def_key:
             temp_list = list(
