@@ -71,8 +71,7 @@ class DynasaurDefinitions:
         """
         self._title = ''
         self._objects = {}
-        self.logger = logger
-        self._logger = self.logger
+        self._logger = logger
         self._info = []
 
         # set all class members
